#!/bin/sh
PN="foldersize"
VERSION="2.5"
RELEASE="1"
PRIORITY="0"
ADVICE=""
TYPE="public"
# all downloads should not have any traling parameters like ?downlaodid=1234 .....(should rewrite in python)
ICON="http://cdn1.iconfinder.com/data/icons/bloggers-1-to-7-vol-PNG/128/left_folder.png"
X86="http://downloads.sourceforge.net/foldersize/FolderSize-2.5-x86.msi"
AMD64="http://downloads.sourceforge.net/foldersize/FolderSize-2.5-x64.msi"
ICONFILE=${ICON##*/}
X86FILE=${X86##*/}
AMD64FILE=${AMD64##*/}

        if [ -e /var/tmp/opsi/upload/$TYPE/${PN}_${VERSION}-${RELEASE}.opsi ]
        then
                echo "package ${PN}_${VERSION}-${RELEASE}.opsi already generated"
                exit 1
        fi

OUT=$(mktemp -d /tmp/output.XXXXXXXXXX) || { echo "Failed to create temp dir"; exit 1; }
mkdir $OUT/$PN
cp -Rv OPSI CLIENT_DATA $OUT/$PN
unix2dos $OUT/$PN/CLIENT_DATA/*

	if [ -e /usr/portage/distfiles/$ICONFILE ]
	then
		if [ -e $ICONFILE.sha1sum ]
		then
			SHA1SUM=`cat $ICONFILE.sha1sum`
			CHECKSUM=`sha1sum /usr/portage/distfiles/$ICONFILE`
			if [ "$CHECKSUM" = "$SHA1SUM" ]
			then
				convert -colorspace rgb /usr/portage/distfiles/$ICONFILE -transparent white -background transparent -resize 160x160\> \
					-size 160x160 xc:transparent +swap -gravity center -composite $OUT/$PN/CLIENT_DATA/$PN.png
#				convert -colorspace rgb /usr/portage/distfiles/$ICONFILE -resize x160 -gravity center -crop 160x160+0+0 +repage $OUT/$PN/CLIENT_DATA/$PN.png

			else
				echo "The checksums do not match."
				exit 1
			fi
		else
			echo "You need to create the checksums with: sha1sum /usr/portage/distfiles/$ICONFILE > $ICONFILE.sha1sum"
			exit 1
		fi
	else
		echo "Downloading file"
		wget -P /usr/portage/distfiles/ $ICON
		exit 1
	fi

	if [ -e /usr/portage/distfiles/$X86FILE ]
	then
		if [ -e $X86FILE.sha1sum ]
		then
			SHA1SUM=`cat $X86FILE.sha1sum`
			CHECKSUM=`sha1sum /usr/portage/distfiles/$X86FILE`
			if [ "$CHECKSUM" = "$SHA1SUM" ]
			then
				cp /usr/portage/distfiles/$X86FILE $OUT/$PN/CLIENT_DATA
			else
				echo "The checksums do not match."
				exit 1
			fi
		else
			echo "You need to create the checksums with: sha1sum /usr/portage/distfiles/$X86FILE > $X86FILE.sha1sum"
			exit 1
		fi
	else
		echo "Downloading file"
		wget -P /usr/portage/distfiles/ $X86
		exit 1
	fi

	if [ -e /usr/portage/distfiles/$AMD64FILE ]
	then
		if [ -e $AMD64FILE.sha1sum ]
		then
			SHA1SUM=`cat $AMD64FILE.sha1sum`
			CHECKSUM=`sha1sum /usr/portage/distfiles/$AMD64FILE`
			if [ "$CHECKSUM" = "$SHA1SUM" ]
			then
				cp /usr/portage/distfiles/$AMD64FILE $OUT/$PN/CLIENT_DATA
			else
				echo "The checksums do not match." 
				exit 1
			fi
		else
			echo "You need to create the checksums with: sha1sum /usr/portage/distfiles/$AMD64FILE > $AMD64FILE.sha1sum"
			exit 1
		fi
	else
		echo "Downloading file"
		wget -P /usr/portage/distfiles/ $AMD64
		exit 1
	fi

sed -e "s!VERSION!$VERSION!g" -e "s!RELEASE!$RELEASE!g" -e "s!PRIORITY!$PRIORITY!g" -e "s!ADVICE!$ADVICE!g" -i $OUT/$PN/OPSI/control
sed -e "s!X86FILE!$X86FILE!g" -e "s!AMD64FILE!$AMD64FILE!g" -i $OUT/$PN/CLIENT_DATA/setup.ins

if test -d ".git"; then
    git log --date-order --date=short | \
    sed -e '/^commit.*$/d' | \
    awk '/^Author/ {sub(/\\$/,""); getline t; print $0 t; next}; 1' | \
    sed -e 's/^Author: //g' | \
    sed -e 's/>Date:   \([0-9]*-[0-9]*-[0-9]*\)/>\t\1/g' | \
    sed -e 's/^\(.*\) \(\)\t\(.*\)/\3    \1    \2/g' > $OUT/$PN/OPSI/changelog.txt
else
    echo "No git repository present."
    exit 1
fi

pushd $OUT
opsi-makeproductfile -v $OUT/$PN
popd

mkdir -p /var/tmp/opsi/upload/$TYPE/
cp -afv $OUT/*.opsi /var/tmp/opsi/upload/$TYPE/

#rm -rf $OUT

